@@ -4,10 +4,8 @@
 # PARAMETER OPTIONAL ecommand: "Select task" TYPE [nohtml:  "(nohtml\) Remove mark-up e.g. HTML tags from an ASCII text file", noreturn: "(noreturn\) Remove carriage return from ASCII file", nospace: "(nospace\) Remove whitespace from an ASCII text file", notab: "(notab\) Replace tabs with spaces in an ASCII text file", trimspace: "(trimspace\) Remove extra whitespace from an ASCII text file"] DEFAULT nohtml (Choose operateion to execute) 
 
 
-# K.M 28.10.2013
-
-
-# pb settings
+source(file.path(chipster.common.path, "zip-utils.R"))
+unzipIfGZipFile("input.txt")
 
 if ( ecommand == "other"){
 	ecommand <- ocommand
